==> affiliate_deeplink-0.1.0.tar.gz: affiliate_deeplink-0.1.0/affiliate_deeplink/config.py <==
import os

AMZ_STORE_NAME = os.getenv('AMZ_STORE_NAME')
BW2_AFL_ID = os.getenv('BW2_AFL_ID')
AFILIO_AFFID = os.getenv('AFILIO_AFFID')
AFILIO_TOKEN = os.getenv('AFILIO_TOKEN')
AFILIO_SITE_ID = os.getenv('AFILIO_SITE_ID')
MGZ_STORE_NAME = os.getenv('MGZ_STORE_NAME')
NATURA_CONSULTORIA_NAME = os.getenv('NATURA_CONSULTORIA_NAME')
BANGGOOD_REFERENCE_ID = os.getenv('BANGGOOD_REFERENCE_ID')
LOMADEE_SOURCE_ID = os.getenv('LOMADEE_SOURCE_ID')
ZANOX_ADS_SPACE_ID = os.getenv('ZANOX_ADS_SPACE_ID')
ZANOX_CONNECT_ID = os.getenv('ZANOX_CONNECT_ID')

ignore_args = ['tag', 'ref', 'linkId',  # amazon
               'p', 'utm_campaign', 'utm_content', 'custlinkid',  # bangood
               'utm_source', 'zanpid', 'utm_medium', 'utm_campaign', 'origem',  # zanox
               'utm_term', 'siteID', 'utm_source', 'utm_medium', 'u1',  # rakuten
               'ranMID', 'utm_term', 'ranSiteID', 'IdParceiro'  # rakuten
               ]

afilio_programs = {
    "walmart.com.br": 191,
    "polishop.com.br": 357,
    "centauro.com.br": 382,
    "latam.com": 483,
    "nespresso.com": 1968,
    "shopfato.com.br": 573,
    "netshoes.com.br": 577,
    "cvc.com.br": 610,
    "mobly.com.br": 764,
    "pontofrio.com.br": 768,
    "extra.com.br": 769,
    "casasbahia.com.br": 770,
    "rihappy.com.br": 928,
    "fastshop.com.br": 994,
    "submarino.com.br": 1008,
    "shoptime.com.br": 1009,
    "americanas.com.br": 1010,
    "oqvestir.com.br": 1086,
    "epocacosmeticos.com.br": 1102,
    "thebeautybox.com.br": 1123,
    "lojaskd.com.br": 1134,
    "cantao.com.br": 1171,
    "posthaus.com.br": 1187,
    "livrariacultura.com.br": 1190,
    "onofreagora.com.br": 1222,
    "wine.com.br": 1225,
    "boticario.com.br": 1255,
    "hopelingerie.com.br": 1260,
    "eudora.com.br": 1318,
    "supermuffato.com.br": 1326,
    "quemdisseberenice.com.br": 1329,
    "megamamute.com.br": 1509,
    "offpremium.com.br": 1534,
    "fyistore.com.br": 1536,
    "animale.com.br": 1537,
    "ikesaki.com.br": 1606,
    "divvino.com.br": 2459,
    "divinoamor.com.br": 1601,
    "natura.com.br": 1604,
    "pontofrioatacado.com.br": 1619,
    "trocafone.com": 1672,
    "cea.com.br": 1678,
    "balaodainformatica.com.br": 1681,
    "afabula.com.br": 1701,
    "maccosmetics.com.br": 2253,
    "onofre.com.br": 1719,
    "madeiramadeira.com.br": 1885,
    "colombo.com.br": 1739,
    "emporio.com": 1754,
    "zattini.com.br": 1785,
    "shopfacil.com.br": 1796,
    "sephora.com.br": 1926,
    "mercatto.com.br": 1830,
    "chicorei.com": 1944,
    "taqi.com.br": 1950,
    "friboi.com.br": 1951,
    "bobstore.com.br": 1959,
    "carrefour.com.br": 2001,
    "korresbr.com.br": 2628,
    "loja.jequiti.com.br": 2495,
    "centralar.com.br": 2168,
    'banggood.com': 2693
}

==> affiliate_deeplink-0.1.3.tar.gz: affiliate_deeplink-0.1.3/affiliate_deeplink/config.py <==
import os

AMZ_STORE_NAME = os.getenv('AMZ_STORE_NAME')
BW2_AFL_ID = os.getenv('BW2_AFL_ID')
AFILIO_AFFID = os.getenv('AFILIO_AFFID')
AFILIO_TOKEN = os.getenv('AFILIO_TOKEN')
AFILIO_SITE_ID = os.getenv('AFILIO_SITE_ID')
MGZ_STORE_NAME = os.getenv('MGZ_STORE_NAME')
NATURA_CONSULTORIA_NAME = os.getenv('NATURA_CONSULTORIA_NAME')
BANGGOOD_REFERENCE_ID = os.getenv('BANGGOOD_REFERENCE_ID')
LOMADEE_SOURCE_ID = os.getenv('LOMADEE_SOURCE_ID')
ZANOX_ADS_SPACE_ID = os.getenv('ZANOX_ADS_SPACE_ID')
ZANOX_CONNECT_ID = os.getenv('ZANOX_CONNECT_ID')

afilio_programs = {
    "walmart.com.br": 191,
    "polishop.com.br": 357,
    "centauro.com.br": 382,
    "latam.com": 483,
    "nespresso.com": 1968,
    "shopfato.com.br": 573,
    "netshoes.com.br": 577,
    "cvc.com.br": 610,
    "mobly.com.br": 764,
    "pontofrio.com.br": 768,
    "extra.com.br": 769,
    "casasbahia.com.br": 770,
    "rihappy.com.br": 928,
    "fastshop.com.br": 994,
    "submarino.com.br": 1008,
    "shoptime.com.br": 1009,
    "americanas.com.br": 1010,
    "oqvestir.com.br": 1086,
    "epocacosmeticos.com.br": 1102,
    "thebeautybox.com.br": 1123,
    "lojaskd.com.br": 1134,
    "cantao.com.br": 1171,
    "posthaus.com.br": 1187,
    "livrariacultura.com.br": 1190,
    "onofreagora.com.br": 1222,
    "wine.com.br": 1225,
    "boticario.com.br": 1255,
    "hopelingerie.com.br": 1260,
    "eudora.com.br": 1318,
    "supermuffato.com.br": 1326,
    "quemdisseberenice.com.br": 1329,
    "megamamute.com.br": 1509,
    "offpremium.com.br": 1534,
    "fyistore.com.br": 1536,
    "animale.com.br": 1537,
    "ikesaki.com.br": 1606,
    "divvino.com.br": 2459,
    "divinoamor.com.br": 1601,
    "natura.com.br": 1604,
    "pontofrioatacado.com.br": 1619,
    "trocafone.com": 1672,
    "cea.com.br": 1678,
    "balaodainformatica.com.br": 1681,
    "afabula.com.br": 1701,
    "maccosmetics.com.br": 2253,
    "onofre.com.br": 1719,
    "madeiramadeira.com.br": 1885,
    "colombo.com.br": 1739,
    "emporio.com": 1754,
    "emporiodacerveja.com.br": 1754,
    "zattini.com.br": 1785,
    "shopfacil.com.br": 1796,
    "sephora.com.br": 1926,
    "mercatto.com.br": 1830,
    "chicorei.com": 1944,
    "taqi.com.br": 1950,
    "friboi.com.br": 1951,
    "bobstore.com.br": 1959,
    "carrefour.com.br": 2829,
    "korresbr.com.br": 2628,
    "loja.jequiti.com.br": 2495,
    "centralar.com.br": 2168,
    'banggood.com': 2693,
    "pt.aliexpress.com": 2351,
    "aliexpress.com": 2351,
}
